.. pyRserve documentation master file

Welcome to pyRserve's documentation!
====================================

pyRServe is a library for connecting Python to an R process running under Rserve.
Through such a connection variables can be get and set in R from Python, 
and also R-functions can be called remotely.

This documentation applies to pyRserve release V |release|

Contents:

.. toctree::
   :maxdepth: 3

   intro
   installation
   manual
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

